@@ -1,6 +1,7 @@
 from __future__ import absolute_import
 
 import ast
+import logging
 import os
 import re
 from hashlib import sha256
@@ -9,6 +10,7 @@ from celery import states as celery_states
 from django import template
 from django.conf import settings as project_settings
 from django.core import validators
+from django.core.exceptions import SuspiciousFileOperation
 from django.db import models
 from django.db.models.signals import post_save
 from django.dispatch import Signal, receiver
@@ -125,6 +127,11 @@ class Build(models.Model):
                 self.image.file
             except IOError:
                 return self.DELETED
+            except SuspiciousFileOperation:
+                msg = ("There is some issue accessing build image file. Check "
+                       "that image.name path is inside image.storage.location.")
+                logging.exception(msg)
+                return 'ACCESS DENIED'
             else: 
                 if self.match_config:
                     return self.AVAILABLE
@@ -453,8 +460,25 @@ class NodeKeys(models.Model):
     PRIVATE = '/etc/uhttpd.key.pem'
     KEY_FILES = [TINC, CERT, PRIVATE]
     
-    ssh_auth = models.TextField('SSH authorized keys', blank=True, null=True,
-            help_text='PEM-encoded RSA public keys allowed for ssh access as root.')
+    allow_node_admins = models.BooleanField('Allow current node admins',
+            default=True,
+            help_text='Enable this option to permanently allow the current '
+                      'group and node administrators\' SSH keys to log into '
+                      'the node as root.')
+    sync_node_admins = models.BooleanField('Synchronize node admins',
+            default=False,
+            help_text='Enable this option to also allow current or future '
+                      'group and node administrators\' SSH keys (as configured '
+                      'in the registry) to log into the node as root. '
+                      'Please note that this may expose your node to an attack '
+                      'if the testbed registry is compromised.')
+    ssh_auth = models.TextField('Additional keys', blank=True, null=True,
+            help_text='Enter additional SSH keys (in "authorized_keys" format) '
+                      'permanently allowed to log into the node as root. '
+                      'You may leave the default keys to allow centralized '
+                      'maintenance of your node by the controller. Please note '
+                      'that this may expose your node to an attack if the '
+                      'controller is compromised.')
     # MD5SUM hashed password in OpenWRT shadow format
     ssh_pass = models.CharField(max_length=128, blank=True, null=True)
     node = models.OneToOneField('nodes.Node', primary_key=True, related_name='keys')
@@ -499,8 +523,9 @@ class NodeBuildFile(models.Model):
     
 
 # Create OneToOne NodeKeys instance on node creation
-@receiver(post_save, sender=Node)
-def create_favorites(sender, instance, created, **kwargs):
+# define a dispatch UID for avoid duplicate signals (#505)
+@receiver(post_save, sender=Node, dispatch_uid="node_keys")
+def create_nodekeys(sender, instance, created, **kwargs):
     if created:
         NodeKeys.objects.create(node=instance)
 
