@@ -2,13 +2,18 @@ from __future__ import absolute_import
 
 from django.shortcuts import get_object_or_404
 from rest_framework import status, exceptions
+from rest_framework.renderers import BrowsableAPIRenderer
 from rest_framework.response import Response
+from rest_framework.settings import api_settings
 from rest_framework.views import APIView
 
 from api import api, generics
+from api.renderers import ResourceListJSONRenderer
 from permissions.api import ApiPermissionsMixin
 
 from .models import Island, Node, Server
+from .renderers import (IslandProfileRenderer, NodeProfileRenderer,
+    ServerProfileRenderer)
 from .serializers import (IslandSerializer, NodeSerializer, NodeCreateSerializer,
     ServerSerializer)
 from .settings import NODES_NODE_API_NODE_BASE_URL
@@ -56,8 +61,8 @@ class RequestCert(APIView):
         self.check_object_permissions(self.request, node)
         try:
             validate_csr(csr, node)
-        except:
-            raise exceptions.ParseError(detail='Malformed CSR')
+        except Exception as e:
+            raise exceptions.ParseError(detail='Malformed CSR: %s' % e.message)
         node.sign_cert_request(csr.strip())
         response_data = {'detail': 'Sign certificate request accepted'}
         return Response(response_data, status=status.HTTP_202_ACCEPTED)
@@ -65,30 +70,34 @@ class RequestCert(APIView):
 
 class NodeList(ApiPermissionsMixin, generics.URIListCreateAPIView):
     """ 
-    **Media type:** [`application/vnd.confine.server.Node.v0+json`](
-        http://wiki.confine-project.eu/arch:rest-api?&#node_at_server)
+    **Media type:** [`application/json;
+        profile="http://confine-project.eu/schema/registry/v0/resource-list"`](
+        http://wiki.confine-project.eu/arch:rest-api#node_at_registry)
     
     This resource lists the [nodes](http://wiki.confine-project.eu/arch:rest-
-    api?&#node_at_server) available in the testbed and provides API URIs to
+    api#node_at_registry) available in the testbed and provides API URIs to
     navigate to them.
     """
     model = Node
     add_serializer_class = NodeCreateSerializer
     serializer_class = NodeSerializer
+    renderer_classes = [ResourceListJSONRenderer, BrowsableAPIRenderer]
     filter_fields = ('arch', 'set_state', 'group', 'group__name')
 
 
 class NodeDetail(generics.RetrieveUpdateDestroyAPIView):
     """
-    **Media type:** [`application/vnd.confine.server.Node.v0+json`](
-        http://wiki.confine-project.eu/arch:rest-api?&#node_at_server)
+    **Media type:** [`application/json;
+        profile="http://confine-project.eu/schema/registry/v0/node"`](
+        http://wiki.confine-project.eu/arch:rest-api#node_at_registry)
     
     This resource describes a node in the testbed as well as listing the
-    [slivers](http://wiki.confine-project.eu/arch:rest-api?&#sliver_at_server)
+    [slivers](http://wiki.confine-project.eu/arch:rest-api?&#sliver_at_registry)
     intended to run on it with API URIs to navigate to them.
     """
     model = Node
     serializer_class = NodeSerializer
+    renderer_classes = [NodeProfileRenderer, BrowsableAPIRenderer]
     ctl = [Reboot, RequestCert]
     
     def get(self, request, *args, **kwargs):
@@ -103,13 +112,15 @@ class NodeDetail(generics.RetrieveUpdateDestroyAPIView):
 
 class ServerDetail(generics.RetrieveUpdateDestroyAPIView):
     """ 
-    **Media type:** [`application/vnd.confine.server.Server.v0+json`](
-        http://wiki.confine-project.eu/arch:rest-api?&#server_at_server)
+    **Media type:** [`application/json;
+        profile="http://confine-project.eu/schema/registry/v0/server"`](
+        http://wiki.confine-project.eu/arch:rest-api#server_at_registry)
     
     This resource describes the testbed server (controller).
     """
     model = Server
     serializer_class = ServerSerializer
+    renderer_classes = [ServerProfileRenderer, BrowsableAPIRenderer]
     
     def get_object(self, *args, **kwargs):
         return get_object_or_404(Server)
@@ -117,31 +128,35 @@ class ServerDetail(generics.RetrieveUpdateDestroyAPIView):
 
 class IslandList(ApiPermissionsMixin, generics.URIListCreateAPIView):
     """
-    **Media type:** [`application/vnd.confine.server.Island.v0+json`](
-        http://wiki.confine-project.eu/arch:rest-api?&#island_at_server)
+    **Media type:** [`application/json;
+        profile="http://confine-project.eu/schema/registry/v0/resource-list"`](
+        http://wiki.confine-project.eu/arch:rest-api#island_at_registry)
     
     This resource lists the network [islands](http://wiki.confine-project.eu/
-    arch:rest-api?&#island_at_server) supported by the testbed and provides
+    arch:rest-api#island_at_registry) supported by the testbed and provides
     API URIs to navigate to them.
     """
     model = Island
     serializer_class = IslandSerializer
+    renderer_classes = [ResourceListJSONRenderer, BrowsableAPIRenderer]
 
 
 class IslandDetail(generics.RetrieveUpdateDestroyAPIView):
     """
-    **Media type:** [`application/vnd.confine.server.Island.v0+json`](
-        http://wiki.confine-project.eu/arch:rest-api?&#island_at_server)
+    **Media type:** [`application/json;
+        profile="http://confine-project.eu/schema/registry/v0/island"`](
+        http://wiki.confine-project.eu/arch:rest-api#island_at_registry)
     
     This resource describes a network island (i.e. a disconnected part of a
     community network) where the testbed is reachable from. A testbed is reachable
     from an island when there is a [gateway](http://wiki.confine-project.eu/arch
-    :rest-api?&#gateway_at_server) that gives access to the testbed server
+    :rest-api?&#gateway_at_registry) that gives access to the testbed server
     (possibly through other gateways), or when the [server](https://wiki.confine
-    -project.eu/arch:rest-api?&#server_at_server) itself is in that island.
+    -project.eu/arch:rest-api?&#server_at_registry) itself is in that island.
     """
     model = Island
     serializer_class = IslandSerializer
+    renderer_classes = [IslandProfileRenderer, BrowsableAPIRenderer]
 
 
 api.register(NodeList, NodeDetail)
