@@ -2,7 +2,7 @@ from celery.task import periodic_task
 from celery.task.schedules import crontab
 from django.db import transaction
 
-from notifications.models import Notification
+from .models import Notification
 
 
 @periodic_task(name="notifications.notify", run_every=crontab(minute=0, hour=0))
@@ -12,5 +12,5 @@ def notify(ids=[]):
     else:
         notifications = Notification.objects.active()
     for notification in notifications:
-        with transaction.commit_on_success():
+        with transaction.atomic():
             notification.process()
