@@ -6,52 +6,17 @@ from controller.forms.widgets import ShowText
 from nodes.models import Node
 
 from .helpers import state_value
-from .models import Slice, Sliver
+from .models import SliverDefaults, Sliver
 
 
-class SliceAdminForm(forms.ModelForm):
-    """ 
-    Provide vlan_nr form field in two flavours, depending on slice state:
-        1) If state is register: checkbox
-        2) If state is not register: read only integer
-    """
-    request_vlan = forms.BooleanField(label='Request VLAN', initial=False, required=False,
-        help_text='VLAN number allocated to this slice by the server.')
-    
+class SliverDefaultsInlineForm(forms.ModelForm):
     class Meta:
-        model = Slice
-    
-    def __init__(self, *args, **kwargs):
-        super(SliceAdminForm, self).__init__(*args, **kwargs)
-        # read only views doens't have fields
-        if 'vlan_nr' in self.fields:
-            if not 'instance' in kwargs:
-                self.fields['vlan_nr'] = self.fields['request_vlan']
-            else:
-                instance = kwargs['instance']
-                if instance.set_state == Slice.REGISTER and instance.vlan_nr == -1:
-                    self.fields['vlan_nr'] = self.fields['request_vlan']
-                    self.initial['vlan_nr'] = True
-                elif instance.set_state == Slice.REGISTER:
-                    self.fields['vlan_nr'] = self.fields['request_vlan']
-                    self.initial['vlan_nr'] = False
-                else:
-                    self.fields['vlan_nr'].widget = ShowText()
-                    self.fields['vlan_nr'].widget.attrs['readonly'] = True
-    
-    def clean_vlan_nr(self):
-        """ Return -1 if user requests vlan_nr """
-        vlan_nr = self.cleaned_data['vlan_nr']
-        if isinstance(vlan_nr, bool):
-            # Register state
-            return None if not vlan_nr else -1
-        # ! Register state: return the old value
-        return self.initial["vlan_nr"]
+        model = SliverDefaults
     
     def clean(self):
         """Clean _uri when uploading a file"""
-        cleaned_data = super(SliceAdminForm, self).clean()
-        for field_name in ('exp_data', 'overlay'):
+        cleaned_data = super(SliverDefaultsInlineForm, self).clean()
+        for field_name in ('data', 'overlay'):
             if cleaned_data.get(field_name):
                 cleaned_data[field_name + "_uri"] = ''
         return cleaned_data
@@ -74,7 +39,7 @@ class SliverAdminForm(forms.ModelForm):
     def clean(self):
         """Clean _uri when uploading a file"""
         cleaned_data = super(SliverAdminForm, self).clean()
-        for field_name in ('exp_data', 'overlay'):
+        for field_name in ('data', 'overlay'):
             if cleaned_data.get(field_name):
                 cleaned_data[field_name + "_uri"] = ''
         return cleaned_data
@@ -99,7 +64,7 @@ class SliceSliversForm(forms.ModelForm):
     def clean(self):
         """Clean _uri when uploading a file"""
         cleaned_data = super(SliceSliversForm, self).clean()
-        for field_name in ('exp_data', 'overlay'):
+        for field_name in ('data', 'overlay'):
             if cleaned_data.get(field_name):
                 cleaned_data[field_name + "_uri"] = ''
         return cleaned_data
