@@ -4,15 +4,19 @@ from django.core.exceptions import ValidationError
 from django.shortcuts import get_object_or_404
 from django.utils.crypto import get_random_string
 from rest_framework import status, exceptions
+from rest_framework.renderers import BrowsableAPIRenderer
 from rest_framework.response import Response
 from rest_framework.reverse import reverse
+from rest_framework.settings import api_settings
 from rest_framework.views import APIView
 
 from api import api, generics
+from api.renderers import ResourceListJSONRenderer
 from controller.core.validators import validate_name
 from permissions.api import ApiPermissionsMixin
 
 from .models import User, Group, Roles
+from .renderers import GroupProfileRenderer, UserProfileRenderer
 from .serializers import (GroupSerializer, GroupCreateSerializer,
     UserSerializer, UserCreateSerializer)
 
@@ -63,16 +67,18 @@ class ChangeAuth(APIView):
 
 class UserList(ApiPermissionsMixin, generics.URIListCreateAPIView):
     """
-    **Media type:** [`application/vnd.confine.server.User.v0+json`](
-        http://wiki.confine-project.eu/arch:rest-api?&#user_at_server)
+    **Media type:** [`application/json;
+        profile="http://confine-project.eu/schema/registry/v0/resource-list"`](
+        http://wiki.confine-project.eu/arch:rest-api#user_at_registry)
     
-    This resource lists the [users](http://wiki.confine-project.eu/arch:rest-api
-    ?&#user_at_server) present in the testbed and provides API URIs to navigate
-    to them.
+    This resource lists the [users](http://wiki.confine-project.eu/arch:rest-
+    api#user_at_registry) present in the testbed and provides API URIs to
+    navigate to them.
     """
     model = User
     add_serializer_class = UserCreateSerializer
     serializer_class = UserSerializer
+    renderer_classes = [ResourceListJSONRenderer, BrowsableAPIRenderer]
 
     def pre_save(self, obj):
         super(UserList, self).pre_save(obj)
@@ -82,8 +88,9 @@ class UserList(ApiPermissionsMixin, generics.URIListCreateAPIView):
 
 class UserDetail(generics.RetrieveUpdateDestroyAPIView):
     """
-    **Media type:** [`application/vnd.confine.server.User.v0+json`](
-        http://wiki.confine-project.eu/arch:rest-api?&#user_at_server)
+    **Media type:** [`application/json;
+        profile="http://confine-project.eu/schema/registry/v0/user"`](
+        http://wiki.confine-project.eu/arch:rest-api#user_at_registry)
     
     This resource describes a person using the testbed.
     """
@@ -91,18 +98,23 @@ class UserDetail(generics.RetrieveUpdateDestroyAPIView):
     serializer_class = UserSerializer
     ctl = [ChangeAuth]
     fields_superuser = ['is_active', 'is_superuser']
+    renderer_classes = [UserProfileRenderer, BrowsableAPIRenderer]
 
 
 class GroupList(ApiPermissionsMixin, generics.URIListCreateAPIView):
     """
-    **Media type:** [`application/vnd.confine.server.Group.v0+json`](
-        http://wiki.confine-project.eu/arch:rest-api?&#group_at_server)
+    **Media type:** [`application/json;
+        profile="http://confine-project.eu/schema/registry/v0/resource-list"`](
+        http://wiki.confine-project.eu/arch:rest-api#group_at_registry)
     
-    This resource describes a group of users using the testbed.
+    This resource lists the [groups](http://wiki.confine-project.eu/arch:rest-
+    api#group_at_registry) present in the testbed and provides API URIs to
+    navigate to them.
     """
     model = Group
     add_serializer_class = GroupCreateSerializer
     serializer_class = GroupSerializer
+    renderer_classes = [ResourceListJSONRenderer, BrowsableAPIRenderer]
     
     def post_save(self, obj, created=False):
         """ user that creates a group becomes its admin """
@@ -111,14 +123,16 @@ class GroupList(ApiPermissionsMixin, generics.URIListCreateAPIView):
 
 class GroupDetail(generics.RetrieveUpdateDestroyAPIView):
     """
-    **Media type:** [`application/vnd.confine.server.Group.v0+json`](
-        http://wiki.confine-project.eu/arch:rest-api?&#group_at_server)
+    **Media type:** [`application/json;
+        profile="http://confine-project.eu/schema/registry/v0/group"`](
+        http://wiki.confine-project.eu/arch:rest-api#group_at_registry)
     
     This resource describes a group of users using the testbed.
     """
     model = Group
     serializer_class = GroupSerializer
     fields_superuser = ['allow_nodes', 'allow_slices']
+    renderer_classes = [GroupProfileRenderer, BrowsableAPIRenderer]
 
 
 api.register(UserList, UserDetail)
